@@ -39,7 +39,7 @@ use SNMP::Info;
 
 use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
 
-$VERSION = '3.10';
+$VERSION = '3.12';
 
 %MIBS = (
     %SNMP::Info::MIBS,
@@ -577,6 +577,13 @@ sub bp_index {
     return \%bp_index;
 }
 
+sub fw_mac {
+    my $airespace = shift;
+    my $partial   = shift;
+
+    return $airespace->SUPER::fw_mac($partial);
+}
+
 sub fw_port {
     my $airespace = shift;
     my $partial   = shift;
