@@ -42,7 +42,7 @@ use SNMP::Info::Layer2;
 
 use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
 
-$VERSION = '3.10';
+$VERSION = '3.12';
 
 %MIBS = (
     %SNMP::Info::Layer2::MIBS,
@@ -334,6 +334,13 @@ sub bp_index {
     return \%bp_index;
 }
 
+sub fw_mac {
+    my $bayhub = shift;
+    my $partial   = shift;
+
+    return $bayhub->SUPER::fw_mac($partial);
+}
+
 sub fw_port {
     my $bayhub  = shift;
     my $partial = shift;
