@@ -49,7 +49,7 @@ use SNMP::Info::LLDP;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
 
-$VERSION = '3.10';
+$VERSION = '3.12';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -198,21 +198,6 @@ sub interfaces {
     return $alu->orig_i_name($partial);
 }
 
-# Use Q-BRIDGE-MIB
-sub fw_mac {
-    my $alu     = shift;
-    my $partial = shift;
-
-    return $alu->qb_fw_mac($partial);
-}
-
-sub fw_port {
-    my $alu     = shift;
-    my $partial = shift;
-
-    return $alu->qb_fw_port($partial);
-}
-
 # Work around buggy bp_index in 6.3.1.871.R01 and 6.3.1.975.R01
 sub bp_index {
     my $alu     = shift;
@@ -445,14 +430,6 @@ to a hash.
 Returns interface name from C<ifName>, since the default return value
 of C<ifDescr> includes the OS version.
 
-=item $alu->fw_mac()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
-=item $alu->fw_port()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
 =item $alu->bp_index()
 
 Work around various bugs in the F<BRIDGE-MIB> and
