@@ -36,19 +36,25 @@ use Exporter;
 use SNMP::Info::Layer3;
 use SNMP::Info::MAU;
 use SNMP::Info::LLDP;
+use SNMP::Info::Aggregate;
 
-@SNMP::Info::Layer3::Arista::ISA = qw/SNMP::Info::LLDP SNMP::Info::MAU
-    SNMP::Info::Layer3 Exporter/;
+@SNMP::Info::Layer3::Arista::ISA = qw/
+    SNMP::Info::Aggregate
+    SNMP::Info::LLDP
+    SNMP::Info::MAU
+    SNMP::Info::Layer3 Exporter
+/;
 @SNMP::Info::Layer3::Arista::EXPORT_OK = qw//;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
 
-$VERSION = '3.10';
+$VERSION = '3.12';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
     %SNMP::Info::MAU::MIBS,
     %SNMP::Info::LLDP::MIBS,
+    %SNMP::Info::Aggregate::MIBS,
     'ARISTA-PRODUCTS-MIB' => 'aristaProducts',
 );
 
@@ -104,22 +110,6 @@ sub model {
     return $model;
 }
 
-# Use Q-BRIDGE-MIB
-
-sub fw_mac {
-    my $arista  = shift;
-    my $partial = shift;
-
-    return $arista->qb_fw_mac($partial);
-}
-
-sub fw_port {
-    my $arista  = shift;
-    my $partial = shift;
-
-    return $arista->qb_fw_port($partial);
-}
-
 # The LLDP MIB leaves it up in the air what the index means.
 # On EOS, it's a dot1d port.
 sub lldp_if {
@@ -141,6 +131,8 @@ sub lldp_if {
     return $lldp_if;
 }
 
+sub agg_ports { return agg_ports_ifstack(@_) }
+
 1;
 __END__
 
@@ -176,6 +168,8 @@ Subclass for Arista Networks EOS-based devices
 
 =over
 
+=item SNMP::Info::Aggregate
+
 =item SNMP::Info::Layer3
 
 =item SNMP::Info::MAU
@@ -194,6 +188,8 @@ Subclass for Arista Networks EOS-based devices
 
 See L<SNMP::Info::Layer3/"Required MIBs"> for its own MIB requirements.
 
+See L<SNMP::Info::Aggregate/"Required MIBs"> for its own MIB requirements.
+
 See L<SNMP::Info::MAU/"Required MIBs"> for its own MIB requirements.
 
 See L<SNMP::Info::LLDP/"Required MIBs"> for its own MIB requirements.
@@ -245,14 +241,6 @@ to a hash.
 
 =over
 
-=item $arista->fw_mac()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
-=item $arista->fw_port()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
 =item $arista->i_duplex_admin()
 
 Returns info from F<MAU-MIB>
@@ -265,6 +253,12 @@ Returns info from F<MAU-MIB>
 
 Returns the mapping to the SNMP Interface Table.
 
+=item C<agg_ports>
+
+Returns a HASH reference mapping from slave to master port for each member of
+a port bundle on the device. Keys are ifIndex of the slave ports, Values are
+ifIndex of the corresponding master ports.
+
 =back
 
 =head2 Table Methods imported from SNMP::Info::Layer3
