@@ -43,7 +43,7 @@ use SNMP::Info::LLDP;
 
 use vars qw/$VERSION $DEBUG %GLOBALS %MIBS %FUNCS %MUNGE/;
 
-$VERSION = '3.10';
+$VERSION = '3.12';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -104,22 +104,6 @@ sub model {
     return $model;
 }
 
-# Use Q-BRIDGE-MIB
-
-sub fw_mac {
-    my $force10 = shift;
-    my $partial = shift;
-
-    return $force10->qb_fw_mac($partial);
-}
-
-sub fw_port {
-    my $force10 = shift;
-    my $partial = shift;
-
-    return $force10->qb_fw_port($partial);
-}
-
 sub v_name {
     my $force10 = shift;
     my $partial = shift;
@@ -300,14 +284,6 @@ Returns reference to hash of arrays:
 key = C<ifIndex>, value = array of VLAN IDs.
 These are the VLANs which are members of the egress list for the port.
 
-=item $force10->fw_mac()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
-=item $force10->fw_port()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
 =item $force10->i_duplex_admin()
 
 Returns info from F<MAU-MIB>
