@@ -39,7 +39,7 @@ use SNMP::Info::LLDP;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
 
-$VERSION = '3.10';
+$VERSION = '3.12';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -113,22 +113,6 @@ sub i_ignore {
     return \%i_ignore;
 }
 
-# Use Q-BRIDGE-MIB
-
-sub fw_mac {
-    my $l3  = shift;
-    my $partial = shift;
-
-    return $l3->qb_fw_mac($partial);
-}
-
-sub fw_port {
-    my $l3  = shift;
-    my $partial = shift;
-
-    return $l3->qb_fw_port($partial);
-}
-
 1;
 __END__
 
@@ -235,14 +219,6 @@ Returns reference to hash.  Increments value of IID if port is to be ignored.
 
 Ignores loopback
 
-=item $h3c->fw_mac()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
-=item $h3c->fw_port()
-
-Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
-
 =back
 
 =head2 Table Methods imported from SNMP::Info::Layer3
