@@ -40,7 +40,7 @@ use SNMP::Info::IEEE802dot11;
 
 use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
 
-$VERSION = '3.10';
+$VERSION = '3.12';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -69,17 +69,17 @@ $VERSION = '3.10';
     ns_i_up          => 'nsIfStatus',
     ns_ip_table      => 'nsIfIp',
     ns_ip_netmask    => 'nsIfNetmask',
-    at_index         => 'nsIpArpIfIdx',
-    at_paddr         => 'nsIpArpMac',
-    at_netaddr       => 'nsIpArpIp',
     bp_index         => 'nsIfInfo',
+    std_at_paddr     => 'ipNetToMediaPhysAddress',
+    ns_at_paddr      => 'nsIpArpMac',
 );
 
 %MUNGE = (
     %SNMP::Info::Layer3::MUNGE,
     %SNMP::Info::IEEE802dot11::MUNGE,
-    'ns_i_mac' => \&SNMP::Info::munge_mac,
-    'at_paddr' => \&SNMP::Info::munge_mac,
+    'ns_i_mac'     => \&SNMP::Info::munge_mac,
+    'ns_at_paddr'  => \&SNMP::Info::munge_mac,
+    'std_at_paddr' => \&SNMP::Info::munge_mac,
 );
 
 sub layers {
@@ -345,30 +345,47 @@ sub _mac_map {
     return \%mac_map;
 }
 
+# Interfaces can have two addresses, we want to capture both the network
+# address and the management address
 sub ip_index {
     my $netscreen = shift;
 
-    my $ns_ip = $netscreen->ns_ip_table() || {};
+    my $ns_ip     = $netscreen->ns_ip_table() || {};
+    my $if_mng_ip = $netscreen->nsIfMngIp()   || {};
 
     my %ip_index = ();
     foreach my $iid ( keys %$ns_ip ) {
         $ip_index{ $ns_ip->{$iid} } = $iid if $ns_ip->{$iid} ne "0.0.0.0";
     }
+    foreach my $iid ( keys %$if_mng_ip ) {
+        $ip_index{ $if_mng_ip->{$iid} } = $iid
+            if $if_mng_ip->{$iid} ne "0.0.0.0";
+    }
     return \%ip_index;
 }
 
 sub ip_table {
     my $netscreen = shift;
 
-    my $ip_index = $netscreen->ip_index() || {};
+    my $ip_index  = $netscreen->ip_index()  || {};
+    my $if_mng_ip = $netscreen->nsIfMngIp() || {};
 
     my %ip_table = ();
     foreach my $iid ( keys %$ip_index ) {
-        $ip_table{$iid} = $iid;
+        my $mgmt_ip = $if_mng_ip->{$iid};
+
+        if ( defined $mgmt_ip && $mgmt_ip ne '0.0.0.0' ) {
+            $ip_table{$iid} = $mgmt_ip;
+        }
+        else {
+            $ip_table{$iid} = $iid;
+        }
     }
     return \%ip_table;
 }
 
+# There is only one netmask for the interface both network and management
+# addresses should have the same netmask
 sub ip_netmask {
     my $netscreen = shift;
 
@@ -461,6 +478,33 @@ sub i_80211channel {
     return \%i_80211channel;
 }
 
+sub at_index {
+    my $netscreen = shift;
+
+    my $std = $netscreen->ipNetToMediaIfIndex();
+    return $std if (ref {} eq ref $std and scalar keys %$std);
+
+    return $netscreen->nsIpArpIfIdx();
+}
+
+sub at_paddr {
+    my $netscreen = shift;
+
+    my $std = $netscreen->std_at_paddr();
+    return $std if (ref {} eq ref $std and scalar keys %$std);
+
+    return $netscreen->ns_at_paddr();
+}
+
+sub at_netaddr {
+    my $netscreen = shift;
+
+    my $std = $netscreen->ipNetToMediaNetAddress();
+    return $std if (ref {} eq ref $std and scalar keys %$std);
+
+    return $netscreen->nsIpArpIp();
+}
+
 1;
 
 __END__
@@ -710,6 +754,33 @@ identifier (IID).
 
 =back
 
+=head2 Arp Cache Table
+
+=over
+
+=item $netscreen->at_index()
+
+Returns reference to hash.  Maps ARP table entries to Interface IIDs 
+
+If the device doesn't support C<ipNetToMediaIfIndex>, this will try
+the proprietary C<nsIpArpIfIdx>.
+
+=item $netscreen->at_paddr()
+
+Returns reference to hash.  Maps ARP table entries to MAC addresses. 
+
+If the device doesn't support C<ipNetToMediaPhysAddress>, this will try
+the proprietary C<nsIpArpMac>.
+
+=item $netscreen->at_netaddr()
+
+Returns reference to hash.  Maps ARP table entries to IP addresses. 
+
+If the device doesn't support C<ipNetToMediaNetAddress>, this will try
+the proprietary C<nsIpArpIp>.
+
+=back
+
 =head3 Wireless Information
 
 =over 
